<?php

namespace Drupal\mailgroup\Plugin\Mailgroup\Connection;

use Drupal\mailgroup\ConnectionBase;
use Fetch\Server;

/**
 * Basic server connection plugin.
 *
 * @Connection(
 *   id = "basic",
 *   label = @Translation("Basic")
 * )
 */
class Basic extends ConnectionBase {

  /**
   * {@inheritdoc}
   */
  public function getFields() {
    $config = $this->configuration;

    $fields['protocol'] = [
      '#type' => 'select',
      '#title' => $this->t('Protocol'),
      '#options' => [
        'imap' => 'IMAP',
        'pop3' => 'POP3',
      ],
      '#default_value' => $config['protocol'] ?? NULL,
    ];

    $fields['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Username'),
      '#default_value' => $config['username'] ?? NULL,
    ];

    $fields['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Password'),
      '#default_value' => $config['password'] ?? NULL,
    ];

    $fields['server'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Server'),
      '#default_value' => $config['server'] ?? NULL,
    ];

    $fields['port'] = [
      '#type' => 'number',
      '#title' => $this->t('Port'),
      '#default_value' => $config['port'] ?? NULL,
    ];

    $fields['secure'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Use SSL/TLS'),
      '#default_value' => $config['secure'] ?? NULL,
    ];

    return $fields;
  }

  /**
   * {@inheritdoc}
   */
  public function testConnection() {
    $config = $this->configuration;

    try {
      $server = new Server($config['server'], $config['port']);
      $server->setAuthentication($config['username'], $config['password']);
      $server->getImapStream();
    }
    catch (\RuntimeException $e) {
      $this->logger->error($e->getMessage());
      return FALSE;
    }

    return TRUE;
  }

}
